# Jenkins를 이용한 지속적인 배포(CI, Continuous Integration)

먼저 웹 소스파일을 개발하고 서버에 업로드하는 일반적인 과정을 살펴보겠습니다.

- [ `STEP 1` ] : PC에 개발소스를 개발하거나 수정한 후 저장

- [ `STEP 2` ] : SFTP/FTP를 이용하여, 웹 소스를 서버에 업로드


과정은 간단하지만, 여기에는 다음과 같은 이슈가 발생 됩니다.

- 개발소스를 개발한 PC에만 최신본이 존재
- 회사PC 등 외부에서 개발한 소스를 최신화하기가 번거로움 (버전관리의 어려움)
- 소스코드 Rollback 의 어려움
  - 의도적인 상황 (소스코드의 잘못된 코딩)
  - 실수가 발생된 상황에 대한 대처 (파일제거/덮어쓰기)

이런 이슈발생을 최소화하기 위해 홍쓰넷에서는 **GitLAB + Jenkins 솔루션**을 제공하여, 개발작업에 편의/관리적 이점을 드리고자 합니다.


# Jenkins 서비스제한 사항

- 호스팅 특성상 Bandwidth는 `30Mbps/s` 입니다.
  - 30Mbps/s 는 전체속도이기 때문에 전체 사용자의 속도에 영향을 받습니다.
  - 무료로 제공되는 서비스인만큼 향후 대역폭 상향은 불가능합니다 (홍쓰넷 관리자도 전체트래픽의 관리가 필요).


# 홍쓰넷 CI/CD 서비스구성도 및 절차

![hongsnet_ci_cd](/uploads/54ca0c85cd5d9a0c9ab59df178146478/hongsnet_ci_cd.png)

- [ `STEP 1` ] : 회원은 할당받은 계정을 이용해 **git(GitLab)** 저장소에 **push**를 수행 합니다.
- [ `STEP 2` ] : GitLab에 설정된 **WebHook 설정**을 이용해서 Jenkins에 Build 합니다.
- [ `STEP 3` ] : 회원 Jenkins 프로젝트의 Build 유발 설정을 작성 합니다.
   - 홍쓰넷에서는 **ssh를 이용한 배포**만 지원 합니다.
   - ssh를 수행하기위해서는 부가서비스를 신청하신 후 **Token 정보**를 받으셔야 합니다.
- [ `STEP 4` ] : 회원은 자신이 개발/변경한 소스코드가 제대로 적용되었는지를 검증 합니다.


# 홍쓰넷 CI/CD 서비스신청 절차

- [ `STEP 1` ] : 홍쓰넷에 로그인 후 MYPAGE로 이동하여, 하단의 서비스추가신청의 **"CI/CD 서비스"** 를 포커스 합니다.

![jenkins_hongs](/uploads/015ab90ae3936c81e860ca56985e9ea8/jenkins_hongs.png)

- [ `STEP 2` ] : **"CI/CD 서비스신청" 버튼**을 클릭하면, 다음과 같이 새창이 출력되면서 신청폼이 나타 납니다.

![jenkins-order2](/uploads/c079fffff49d8d238adf1743710e5ee9/jenkins-order2.png)


- [ `STEP 3` ] : GIT/JENKINS 를 모두 신청 합니다(각각 신청필요).

그럼 페이지 하단이력에 다음과 같이 **두 건의 접수완료가 접수 됩니다.**

![jenkins-order3](/uploads/28bf2bce827298ed00da32b0d4fda6f9/jenkins-order3.png)

> 주의 : Jenkins를 신청하시려면, 먼저 Git의 신청 및 처리가 완료되어야 합니다.


여기까지 완료되었으면, 관리자의 처리를 기다리셔야 합니다.

- [ `STEP 4` ] : 처리가 완료되면, 다음과 같이 **Token 정보**가 생성됩니다.

![jenkins_hongs2](/uploads/9626e53856163b2f4af717af306ae0e6/jenkins_hongs2.png)


여기까지 완료되었으면, Jenkins의 CI/CD 설정만 남게되며 다음의 절차대로 진행 됩니다.

- GitLAB ID/PW, Project, WebHook -> `관리자가 세팅`
- Jenkins ID/PW, Project -> `관리자가 세팅`
- CI/CD 적용 -> `회원이 세팅`



